pub struct EngineBase<D, Q, A>{ /* private fields */ }Expand description
The EngineBase implementation is designed as a type of runtime for executing various
Turing machine models, or drivers, according to a specified set of rules encapsulated
within a Program<Q, A>.
Implementations
Sourceimpl<D, Q, A> EngineBase<D, Q, A>
impl<D, Q, A> EngineBase<D, Q, A>
Sourcepub fn from_program(program: Program<Q, A>) -> Selfwhere
D: Default,
pub fn from_program(program: Program<Q, A>) -> Selfwhere
D: Default,
initialize a new instance of the engine using the default driver and given program
Sourcepub fn from_driver_with_input<I>(driver: D, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
pub fn from_driver_with_input<I>(driver: D, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
initialize a new engine using the given driver and program
Sourcepub const fn from_driver(driver: D) -> Self
pub const fn from_driver(driver: D) -> Self
initialize a new instance of the engine from the given driver
Sourcepub fn load(self, program: Program<Q, A>) -> Self
pub fn load(self, program: Program<Q, A>) -> Self
load a new program into the engine and return a mutable reference to self
Sourcepub fn with_tape<I>(self, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
pub fn with_tape<I>(self, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
consumes the current instance to create another with the given tape input
Sourcepub fn set_program(&mut self, program: Program<Q, A>)
pub fn set_program(&mut self, program: Program<Q, A>)
update the current program for the engine
Sourcepub fn with_driver<D2>(self, driver: D2) -> EngineBase<D2, Q, A> ⓘwhere
D2: Driver<Q, A>,
pub fn with_driver<D2>(self, driver: D2) -> EngineBase<D2, Q, A> ⓘwhere
D2: Driver<Q, A>,
consumes the engine to create another with the given driver
Sourcepub fn with_program(self, program: Program<Q, A>) -> Self
pub fn with_program(self, program: Program<Q, A>) -> Self
consumes the current instance to create another with the given program
Sourcepub const fn cycles(&self) -> usize
pub const fn cycles(&self) -> usize
returns a copy of the total number of cycles, or steps, the engine has preformed
Sourcepub const fn driver_mut(&mut self) -> &mut D
pub const fn driver_mut(&mut self) -> &mut D
returns a mutable reference to the actor
Sourcepub const fn program_mut(&mut self) -> Option<&mut Program<Q, A>>
pub const fn program_mut(&mut self) -> Option<&mut Program<Q, A>>
returns a mutable reference to the program
Sourcepub fn current_position(&self) -> usize
pub fn current_position(&self) -> usize
returns the current position of the driver
Sourcepub fn current_state(&self) -> State<&Q>
pub fn current_state(&self) -> State<&Q>
returns a view of the current state of the driver
Sourcepub const fn has_program(&self) -> bool
pub const fn has_program(&self) -> bool
returns true if the engine has a program loaded
Sourcepub fn extend_tape<I>(&mut self, iter: I)where
I: IntoIterator<Item = A>,
pub fn extend_tape<I>(&mut self, iter: I)where
I: IntoIterator<Item = A>,
extend the output tape with values from the given iterator
Sourcepub fn find_tail<K>(&self, state: State<&Q>, symbol: &A) -> Option<&Tail<Q, A>>
pub fn find_tail<K>(&self, state: State<&Q>, symbol: &A) -> Option<&Tail<Q, A>>
returns the tail associated with the head that is equal to the given state and symbol
Sourcepub const fn next_cycle(&mut self)
pub const fn next_cycle(&mut self)
increments the current epoch by a single unit indicating the end of a cycle or step
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
reset the engine by clearing the output tape, cycles, and program from the current instance
Sourcepub fn is_halted(&self) -> boolwhere
Q: Halting,
pub fn is_halted(&self) -> boolwhere
Q: Halting,
returns true if the driver is in a halted state
Sourcepub fn run(&mut self) -> Result<()>
pub fn run(&mut self) -> Result<()>
runs the program until termination (i.e., a halt state is reached, an error occurs, etc.)
Sourcepub fn pretty_print(&self) -> Stringwhere
A: Debug,
pub fn pretty_print(&self) -> Stringwhere
A: Debug,
a string representation of the driver’s tape with the current head position highlighted
in brackets. 0, 1, 0, [1], 1, 0, 0 for a radius of 3.
Sourcepub fn print(&self) -> Stringwhere
A: Display,
pub fn print(&self) -> Stringwhere
A: Display,
returns a string representation of the tape with the current head position highlighted in brackets.
Sourcepub fn read(&self) -> Result<&A>
pub fn read(&self) -> Result<&A>
read the current symbol at the head of the tape into the internal buffer
Sourcepub fn read_head(&self) -> Result<Head<&Q, &A>>
pub fn read_head(&self) -> Result<Head<&Q, &A>>
read and return the current head of the machine
Sourcepub fn read_uninit(&self) -> Head<&Q, MaybeUninit<&A>>
pub fn read_uninit(&self) -> Head<&Q, MaybeUninit<&A>>
Reads the current symbol at the head of the tape
Sourceimpl<Q, A> EngineBase<Head<Q, usize>, Q, A>
impl<Q, A> EngineBase<Head<Q, usize>, Q, A>
Sourcepub fn tmh(program: Program<Q, A>) -> Self
pub fn tmh(program: Program<Q, A>) -> Self
initialize a new instance of a turing machine with a moving head using the given program.
Sourcepub fn from_state_with_input<I>(state: Q, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
pub fn from_state_with_input<I>(state: Q, input: I) -> Selfwhere
I: IntoIterator<Item = A>,
initialize a new instance of the TMH engine from the given state and input