Halt

Enum Halt 

#[repr(C)]
pub enum Halt<Q = usize, H = Q>
where Q: RawState, H: RawState,
{ Halt(H), Step(Q), }
The Halt implementation is a binary enum designed to represent either a halting state or a stepping state within a Turing machine or similar computational model.

Variants



Halt(H)



Step(Q)

Implementations

Source

impl<Q, H> Halt<Q, H>
where Q: RawState, H: RawState,

pub const fn is_halt(&self) -> bool

Returns true if the enum is Halt::Halt otherwise false

pub const fn is_step(&self) -> bool

Returns true if the enum is Halt::Step otherwise false

Source

impl<Q, H> Halt<Q, H>
where Q: RawState, H: RawState,

pub const fn from_halt(state: H) -> Halt<Q, H>

Creates a new instance of a Halt with a halted state.

pub const fn from_state(state: Q) -> Halt<Q, H>

Creates a new instance of a Halt with a continuing state.

pub const fn swap(&mut self, other: &mut Halt<Q, H>)

swap the inner value of the halt state with that of the given state.

pub const fn view(&self) -> Halt<&Q, &H>

returns a new instance of the halt state containing a reference to its inner value.

pub const fn view_mut(&mut self) -> Halt<&mut Q, &mut H>

returns a new instance of the halt state containing a mutable reference to its inner value.

pub fn to_owned(&self) -> Halt<Q, H>
where Q: Clone, H: Clone,

returns an owned version of the current haltable state

Source

impl<Q> Halt<Q>
where Q: RawState,

pub fn into_inner(self) -> Q

consumes the current haltable state, returning the inner state.

pub fn halt(self) -> Halt<Q>

consumes the current instance to ensure a halting state

pub fn into_state(self) -> State<Q>

consumes the current haltable state, returning the inner state.

pub fn into_halt_state(self) -> State<Halt<Q>>

consumes the current instance to initialize a wrapper instance

pub const fn as_halt_state(&self) -> State<Halt<&Q>>

returns a wrapped instance of the halt state containing a reference to its inner value.

pub const fn as_mut_halt_state(&mut self) -> State<Halt<&mut Q>>

returns a wrapped instance of the halt state containing a mutable reference to its inner value.

pub const fn as_state(&self) -> State<&Q>

returns a wrapped reference to the inner value

pub const fn as_mut_state(&mut self) -> State<&mut Q>

returns a wrapped mutable reference to the inner value

pub const fn get(&self) -> &Q

returns a reference to the internal state

pub const fn get_mut(&mut self) -> &mut Q

returns a mutable reference to the internal state

pub const fn replace(&mut self, state: Q) -> Q

replace the inner value of the halt state with the given state.

pub fn set(&mut self, state: Q)

update the current inner state without affecting the status of the state.

Source

impl<'a, Q, H> Halt<&'a Q, &'a H>
where Q: RawState, H: RawState,

pub fn cloned(self) -> Halt<Q, H>
where Q: Clone, H: Clone,

consumes the current instance of the halt state to create another with cloned inner values.

pub fn copied(self) -> Halt<Q, H>
where Q: Copy, H: Copy,

consumes the current instance of the halt state to create another with copied inner values.

Note: This method does not mutate the specified variant.

Source

impl<'a, Q, H> Halt<&'a mut Q, &'a mut H>
where Q: RawState, H: RawState,

pub fn cloned(self) -> Halt<Q, H>
where Q: Clone, H: Clone,

consumes the current instance of the halt state to create another with cloned inner values.

pub fn copied(self) -> Halt<Q, H>
where Q: Copy, H: Copy,

consumes the current instance of the halt state to create another with copied inner values.