This module provides the ProgramBase implementation along with its associated aliases,
supporting traits, and more.
Structs
- Instruction
Set Deprecated - The implementation is designed to provide a structured representation of a set of rules and an optional initial state for a Turing machine or similar computational model. It encapsulates the rules that dictate the machine’s behavior and the starting point for its execution.
- Program
Base - The
ProgramBasestruct is used to define a generic program capable of being executed by a Turing machine or similar computational model. It consists of an optional initial state, a set of rules (or instructions) used to indicate how the machine should respond under different circumstances, and a marker to associate the generic parameters with the struct.
Traits
- RawRuleset
- The
RawRulesettrait establishes an interface common to all compatible sets of rules for the framework. - Rule
SetMut - Ruleset
Type Aliases
- Program
- a type alias for a
ProgramBaseusing aVecas the ruleset - Program
Array - ProgramB
Map - ProgramB
Set - Program
Map - a type alias for a
ProgramBaseusing aHashMapas the ruleset, using the head as key and the tail as value - Program
Set - a type alias for a
ProgramBaseusing aHashSetconsisting of rules as the store - Program
Slice - A type alias for a
ProgramBaseconfigured to use a slice of rules as the ruleset, with default generic parameters for the state and action types