Tail

Struct Tail 

#[repr(C)]
pub struct Tail<Q, A> { pub direction: Direction, pub next_state: State<Q>, pub write_symbol: A, }
The Tail of a rule defines the reaction of the actor under specific conditions. Specifically, it defines the next state, the symbol to write, and the direction to move

Fields

direction: Direction

defines the direction to move after writing the symbol

next_state: State<Q>write_symbol: A

Implementations

Source

impl<Q, A> Tail<Q, A>
where Q: RawState,

pub const fn new(direction: Direction, next_state: Q, write_symbol: A) -> Self

initializes a new Tail with the given direction, state, and symbol

pub const fn stay(state: Q, symbol: A) -> Self

initializes a new Tail at rest using the given state and symbol

pub const fn left(state: Q, symbol: A) -> Self

initializes a new Tail moving to the left using the given state and symbol

pub const fn right(state: Q, symbol: A) -> Self

initializes a new Tail moving to the right using the given state and symbol

pub fn from_head(head: Head<Q, A>) -> Self

returns a new instance of the Tail using the given direction and head

pub fn from_head_with_direction(head: Head<Q, A>, direction: Direction) -> Self

pub const fn as_tuple(&self) -> (Direction, &State<Q>, &A)

returns the direction, state, and symbol as a 3-tuple

pub fn into_tuple(self) -> (Direction, State<Q>, A)

consumes the tail and returns the direction, state, and symbol as a 3-tuple

pub const fn direction(&self) -> Direction

returns a copy of the direction the head should shift after writing the symbol and updating the state.

pub const fn state(&self) -> &State<Q>

returns the next state with an immutable reference to the inner value

pub const fn state_mut(&mut self) -> &mut State<Q>

returns the next state with a mutable reference to the inner value

pub const fn symbol(&self) -> &A

returns the symbol the head is instructed to write

pub const fn symbol_mut(&mut self) -> &mut A

returns a mutable reference to the symbol of the tail

pub const fn set_direction(&mut self, direction: Direction)

update the direction of the tail

pub fn set_state(&mut self, state: Q)

update the configured state for the tail

pub fn set_symbol(&mut self, symbol: A)

update the defined symbol for the tail

pub fn with_direction(self, direction: Direction) -> Self

consumes the current instance to create another with the given Direction

pub fn with_state(self, state: Q) -> Self

consumes the current instance to create another with the given state

pub fn with_symbol(self, symbol: A) -> Self

Configures the tail with a new symbol

pub const fn get_head(&self) -> Head<&Q, &A>

returns an instance of the Head containing references to the next state and symbol.

pub fn get_head_mut(&mut self) -> Head<&mut Q, &mut A>

returns a new Head initialized with mutable references to the state and symbol

pub fn into_head(self) -> Head<Q, A>

consumes the current instance of the tail to convert it into a Head containing the next state and symbol to write.

pub fn into_head_tuple(self) -> (Direction, Head<Q, A>)

convert the tail into a 2-tuple consisting of a Direction and a Head

pub const fn view(&self) -> Tail<&Q, &A>

returns an instance of the head where each element within the created instance is a mutable reference

pub const fn view_mut(&mut self) -> Tail<&mut Q, &mut A>

returns a new Tail containing mutabl references to the state and symbol

Source

impl<'a, Q, S> Tail<&'a Q, &'a S>
where Q: RawState,

pub fn cloned(&self) -> Tail<Q, S>
where Q: Clone, S: Clone,

returns a new Tail with cloned elements

pub const fn copied(&self) -> Tail<Q, S>
where Q: Copy, S: Copy,

returns a new Tail with copied elements

Source

impl<'a, Q, S> Tail<&'a mut Q, &'a mut S>
where Q: RawState,

pub fn cloned(&self) -> Tail<Q, S>
where Q: Clone, S: Clone,

returns a new Tail with cloned elements

pub const fn copied(&self) -> Tail<Q, S>
where Q: Copy, S: Copy,

returns a new Tail with copied elements