HeadStep

Struct HeadStep 

pub struct HeadStep<'a, Q1, A1, Q2 = Q1, A2 = A1>
where Q1: RawState, Q2: RawState,
{ /* private fields */ }
HeadStep defines a lazy stepper for a Turing machine configured with a so-called moving head.

Implementations

Source

impl<'a, Q, A> HeadStep<'a, Q, A>
where Q: RawState,

the standard implementation of HeadStep focuses on instances where the head and tail share the same type-space; meaning Head<Q, A> and Tail<Q, A> types are being utilized.

pub fn apply(self) -> Head<Q, A>

apply the step, mutating the head according to the tail’s instructions before returning the previous head value.

pub fn move_along(self, tape: &mut [A], pos: &mut usize) -> Head<Q, A>
where A: Clone,

this method performs the step operation onto the tape, assuming the head’s symbol to be

Source

impl<'a, Q, A> HeadStep<'a, Q, usize, Q, A>
where Q: RawState,

this implementation of the HeadStep is specifically designed for scenarios where the head’s symbol is used to define the position

pub fn shift(self, tape: &mut [A]) -> Result<Head<Q, A>>
where A: Clone,

this method shifts the head along the tape, returning a head containing the previous state and symbol.

note: this method does not check if the current nor the next state is halted, it is up to the caller to establishing halting.