pub struct ProgramBase<R, Q, A, I = <R as RawRuleset<Q, A>>::Rule>{ /* private fields */ }Expand description
The ProgramBase struct is used to define a generic program capable of being executed by
a Turing machine or similar computational model. It consists of an optional initial state,
a set of rules (or instructions) used to indicate how the machine should respond under
different circumstances, and a marker to associate the generic parameters with the struct.
Implementations
Sourceimpl<R, I, Q, A> ProgramBase<R, Q, A, I>
impl<R, I, Q, A> ProgramBase<R, Q, A, I>
Sourcepub const fn from_rules(rules: R) -> Self
pub const fn from_rules(rules: R) -> Self
initialize a new program from the given rule set
Sourcepub fn initial_state(&self) -> Option<&State<Q>>
pub fn initial_state(&self) -> Option<&State<Q>>
returns reference to the (optional) initial state
Sourcepub fn set_initial_state(&mut self, initial_state: Q)
pub fn set_initial_state(&mut self, initial_state: Q)
configure the initial state
Sourcepub fn with_default_state<U>(self, initial_state: U) -> Selfwhere
U: IntoState<Q>,
pub fn with_default_state<U>(self, initial_state: U) -> Selfwhere
U: IntoState<Q>,
consumes the instance to create another with the given initial state
pub fn get_head(&self, head: &Head<Q, A>) -> Option<&Tail<Q, A>>
Sourceimpl<I, Q, A> ProgramBase<[I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
impl<I, Q, A> ProgramBase<[I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
Sourceimpl<I, Q, A> ProgramBase<&[I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
impl<I, Q, A> ProgramBase<&[I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
Sourceimpl<I, Q, A> ProgramBase<&mut [I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
impl<I, Q, A> ProgramBase<&mut [I], Q, A, I>where
Q: RawState,
I: Instruction<Q, A>,
Sourceimpl<const N: usize, I, Q, A> ProgramBase<[I; N], Q, A>where
Q: RawState,
I: Instruction<Q, A>,
impl<const N: usize, I, Q, A> ProgramBase<[I; N], Q, A>where
Q: RawState,
I: Instruction<Q, A>,