Rule

Struct Rule 

#[repr(C)]
pub struct Rule<Q1 = String, A = char, Q2 = Q1, B = A>
where Q1: RawState, Q2: RawState,
{ pub head: Head<Q1, A>, pub tail: Tail<Q2, B>, }
The Rule implementation is a concrete representation of a single instruction, or rule, within a given Turing machine program. It encapsulates the necessary components to define the behavior of the Turing machine when it encounters a specific state and symbol.

Note: The inner fields are flattened for serialization purposes when using serde; this means that the fields of the Head and Tail structs will be serialized as if they were direct fields of the Rule struct itself.

Fields

head: Head<Q1, A>tail: Tail<Q2, B>

Implementations

Source

impl<Q, A, R, B> Rule<Q, A, R, B>
where Q: RawState, R: RawState,

pub const fn new(head: Head<Q, A>, tail: Tail<R, B>) -> Self

returns a new instance of the Rule from the given head and tail

pub const fn init() -> RuleBuilder<Q, A, R, B>

returns a new instance of a RuleBuilder for constructing a new Rule

pub const fn from_parts( state: Q, symbol: A, direction: Direction, next_state: R, write_symbol: B, ) -> Self

initialize a new instance of the Rule from its consituent parts

pub fn with_head(self, head: Head<Q, A>) -> Self

consumes the current object to create another with the given head

pub fn with_tail(self, tail: Tail<R, B>) -> Self

consumes the current object to create another with the given tail

pub const fn head(&self) -> &Head<Q, A>

returns an immutable reference to the Head

pub const fn head_mut(&mut self) -> &mut Head<Q, A>

returns a mutable reference to the Head

pub const fn tail(&self) -> &Tail<R, B>

returns an immutable reference to the Tail of the Rule

pub const fn tail_mut(&mut self) -> &mut Tail<R, B>

returns a mutable reference to the Tail of the Rule

pub const fn head_view(&self) -> Head<&Q, &A>

returns an instance of the Head whose elements are immutable references

pub const fn tail_view(&self) -> Tail<&R, &B>

returns an instance of the Tail whose elements are immutable references

pub const fn direction(&self) -> Direction

returns the direction of the shift

pub const fn state(&self) -> &State<Q>

returns the current State of the system

pub const fn state_mut(&mut self) -> &mut State<Q>

returns a mutable reference to the current State of the system

pub const fn symbol(&self) -> &A

returns the symbol of the Head

pub const fn symbol_mut(&mut self) -> &mut A

returns a mutable reference to the symbol of the Head

pub const fn next_state(&self) -> &State<R>

returns the next State of the system

pub const fn next_state_mut(&mut self) -> &mut State<R>

returns a mutable reference to the next State of the system

pub const fn next_symbol(&self) -> &B

returns the symbol which will be written by the Head

pub const fn next_symbol_mut(&mut self) -> &mut B

returns a mutable reference to the next symbol

pub const fn write_symbol(&self) -> &B

returns the value which for which the current object will be replaced with

pub const fn write_symbol_mut(&mut self) -> &mut B

returns a mutable reference to the next symbol

pub fn set_direction(&mut self, direction: Direction)

updates the current Direction and returns a mutable reference to the Rule

pub fn set_symbol(&mut self, symbol: A)

update the current symbol and return a mutable reference to the Rule

pub fn set_state(&mut self, state: Q)

updates the current State and returns a mutable reference to the Rule

pub fn set_next_state(&mut self, state: R)

updates the current State and returns a mutable reference to the Rule

pub fn set_next_symbol(&mut self, symbol: B)

updates the next symbol and returns a mutable reference to the Rule

pub fn set_head(&mut self, state: Q, symbol: A)

updates the current State and symbol and returns a mutable reference to the Rule

pub fn set_tail(&mut self, state: R, symbol: B)

updates the current State and symbol and returns a mutable reference to the Rule

pub fn into_tuple(self) -> (Head<Q, A>, Tail<R, B>)

consumes the current object and returns a 2-tuple consisting of the Head and Tail

pub const fn next_head(&self) -> Head<&R, &B>

returns the next Head of the system

pub fn into_next_head(self) -> Head<R, B>

consumes the current object and returns the next Head of the system

Source

impl<Q, A, R, B> Rule<&Q, &A, &R, &B>
where Q: RawState, R: RawState,

pub fn cloned(&self) -> Rule<Q, A, R, B>
where Q: Clone, A: Clone, R: Clone, B: Clone,

returns a new instance of the Rule with cloned elements

pub const fn copied(&self) -> Rule<Q, A, R, B>
where Q: Copy, A: Copy, R: Copy, B: Copy,

returns a new instance of the Rule with copied elements

Source

impl<Q, A> Rule<Q, usize, Q, A>
where Q: RawState,

pub fn shift(&mut self, tape: &mut [A]) -> Option<Head<Q, A>>
where A: Clone, Q: Clone,

this method shifts the head along the tape, returning a head containing the previous state and symbol.

note: this method does not check if the current nor the next state is halted, it is up to the caller to establishing halting.