#[repr(transparent)]pub struct State<Q = bool>(pub Q)
where
Q: ?Sized;Expand description
The State wrapper is a generic container used to denote objects being used as a
state in a Turing machine, finite-state machine, or similar computational model.
Tuple Fields
0: QImplementations
Sourceimpl<Q> State<Q>
impl<Q> State<Q>
Sourcepub fn init<F>(f: F) -> State<Q>where
F: FnOnce() -> Q,
pub fn init<F>(f: F) -> State<Q>where
F: FnOnce() -> Q,
create a new state by invoking the given function and capturing its output.
Sourcepub const fn as_ptr(&self) -> *const Q
pub const fn as_ptr(&self) -> *const Q
returns a new instance of state with a raw pointer to the inner value.
Sourcepub const fn as_mut_ptr(&mut self) -> *mut Q
pub const fn as_mut_ptr(&mut self) -> *mut Q
returns a new instance of state with a mutable raw pointer to the inner value.
Sourcepub const fn get_mut(&mut self) -> &mut Q
pub const fn get_mut(&mut self) -> &mut Q
returns a mutable reference to the inner value of the state.
Sourcepub fn map<R, F>(self, f: F) -> State<R>where
F: FnOnce(Q) -> R,
pub fn map<R, F>(self, f: F) -> State<R>where
F: FnOnce(Q) -> R,
State::map applies the given function onto the inner value of the state, returning a new state with the result.
Sourcepub fn reset(&mut self) -> State<Q>where
Q: Default,
pub fn reset(&mut self) -> State<Q>where
Q: Default,
reset the state back to its logical default, returning the previous value.
Sourcepub const fn replace(&mut self, state: Q) -> Q
pub const fn replace(&mut self, state: Q) -> Q
replace the inner value of the state with the given state,
Sourcepub const fn swap(&mut self, other: &mut State<Q>)
pub const fn swap(&mut self, other: &mut State<Q>)
swap the inner value of the state with that of the given state.
Sourcepub fn take(&mut self) -> Qwhere
Q: Default,
pub fn take(&mut self) -> Qwhere
Q: Default,
take the inner value of the state, leaving the logical default in
its place
Sourcepub fn as_halt(&self) -> State<Halt<&Q>>where
Q: RawState,
pub fn as_halt(&self) -> State<Halt<&Q>>where
Q: RawState,
converts the current reference into a haltable state initialized with the current state
Sourcepub fn into_halt(self) -> State<Halt<Q>>where
Q: RawState,
pub fn into_halt(self) -> State<Halt<Q>>where
Q: RawState,
consumes the wrapper to create another, haltable state that is initialized with the current state
Sourcepub fn halt(self) -> State<Halt<Q>>where
Q: RawState,
pub fn halt(self) -> State<Halt<Q>>where
Q: RawState,
consumes the current state, returning a new one with a Halt
variant initialized with the current value.
Sourcepub const fn view_mut(&mut self) -> State<&mut Q>
pub const fn view_mut(&mut self) -> State<&mut Q>
returns a state with a mutable reference to the inner value.
Sourcepub fn get_inner_type_name(&self) -> &'static str
pub fn get_inner_type_name(&self) -> &'static str
returns the name of the generic inner type, Q.
Sourcepub const fn get_inner_type_id(&self) -> TypeIdwhere
Q: 'static,
pub const fn get_inner_type_id(&self) -> TypeIdwhere
Q: 'static,
returns the type id of the generic inner type, Q.
Sourceimpl<Q> State<Q>
Additional implementations for the State type enabled whenever the alloc feature is
toggled.
impl<Q> State<Q>
Additional implementations for the State type enabled whenever the alloc feature is
toggled.
Sourcepub fn as_any(&self) -> State<Box<dyn Any>>where
Q: Clone + 'static,
pub fn as_any(&self) -> State<Box<dyn Any>>where
Q: Clone + 'static,
Converts the inner type into a boxed “any” state, returning a new instance of state
Sourcepub fn into_any(self) -> State<Box<dyn Any>>where
Q: 'static,
pub fn into_any(self) -> State<Box<dyn Any>>where
Q: 'static,
Converts the inner type into a boxed “any” state, returning a new instance of state
convert the state into another instance by wrapping the inner value with an Arc.
returns a shared reference to the state.
Sourceimpl<Q> State<*mut Q>
impl<Q> State<*mut Q>
Sourcepub fn from_mut_ptr(ptr: *mut Q) -> State<*mut Q>
pub fn from_mut_ptr(ptr: *mut Q) -> State<*mut Q>
Creates a new instance of state with a mutable raw pointer to the inner value.
Sourceimpl<Q> State<MaybeUninit<Q>>
impl<Q> State<MaybeUninit<Q>>
Sourcepub const fn initialized(value: Q) -> State<MaybeUninit<Q>>
pub const fn initialized(value: Q) -> State<MaybeUninit<Q>>
Creates a new instance of state with an initialized inner value.
Sourcepub const fn uninit() -> State<MaybeUninit<Q>>
pub const fn uninit() -> State<MaybeUninit<Q>>
Creates a new instance of state with an uninitialized inner value.
Sourcepub unsafe fn assume_init(self) -> State<Q>
pub unsafe fn assume_init(self) -> State<Q>
Sourceimpl State<Box<dyn Any>>
impl State<Box<dyn Any>>
Sourcepub fn downcast<Q>(self) -> Result<State<Box<Q>>, StateError>where
Q: Any,
pub fn downcast<Q>(self) -> Result<State<Box<Q>>, StateError>where
Q: Any,
Attempts to downcast the state to a concrete type Q; returns an error if the state
is not of type Q.