StateExt

Trait StateExt 

pub trait StateExt:
    HaltingState
    + Clone
    + Default
    + PartialEq
    + PartialOrd
    + Debug
    + Display { }
The StateExt trait is used to extend the base RawState trait, introducing additional traits and constraints that are commonly required for state representations.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors