ProgramBase

Struct ProgramBase 

pub struct ProgramBase<R, Q, A, I = <R as RawRuleset<Q, A>>::Rule>
where Q: RawState, R: RawRuleset<Q, A, Rule = I> + ?Sized, I: Instruction<Q, A>,
{ /* private fields */ }
The ProgramBase struct is used to define a generic program capable of being executed by a Turing machine or similar computational model. It consists of an optional initial state, a set of rules (or instructions) used to indicate how the machine should respond under different circumstances, and a marker to associate the generic parameters with the struct.

Implementations

Source

impl<R, I, Q, A> ProgramBase<R, Q, A, I>
where Q: RawState, R: RawRuleset<Q, A, Rule = I>, I: Instruction<Q, A>,

pub const fn from_rules(rules: R) -> Self

initialize a new program from the given rule set

pub const fn rules(&self) -> &R

returns a reference to the ruleset

pub fn initial_state(&self) -> Option<&State<Q>>

returns reference to the (optional) initial state

pub fn set_initial_state(&mut self, initial_state: Q)

configure the initial state

pub fn with_default_state<U>(self, initial_state: U) -> Self
where U: IntoState<Q>,

consumes the instance to create another with the given initial state

pub fn get_head(&self, head: &Head<Q, A>) -> Option<&Tail<Q, A>>
where R: Ruleset<Q, A>, R::Rule: Instruction<Q, A, Head = Head<Q, A>, Tail = Tail<Q, A>>,

pub fn find_tail(&self, state: State<&Q>, sym: &A) -> Option<&Tail<Q, A>>
where R: Ruleset<Q, A>, R::Rule: Instruction<Q, A, Head = Head<Q, A>, Tail = Tail<Q, A>>,

given a state and symbol, returns the corresponding tail if it exists within the ruleset

pub fn len(&self) -> usize

returns the number of rules within the ruleset

pub fn is_empty(&self) -> bool

returns true if the ruleset is considered empty (i.e. contains no rules), otherwise false.

Source

impl<I, Q, A> ProgramBase<[I], Q, A, I>
where Q: RawState, I: Instruction<Q, A>,

pub fn iter(&self) -> Iter<'_, I>

returns an iterator over the elements.

pub fn iter_mut(&mut self) -> IterMut<'_, I>

returns a mutable iterator over the elements.

Source

impl<I, Q, A> ProgramBase<&[I], Q, A, I>
where Q: RawState, I: Instruction<Q, A>,

pub fn iter(&self) -> Iter<'_, I>

returns an iterator over the elements.

Source

impl<I, Q, A> ProgramBase<&mut [I], Q, A, I>
where Q: RawState, I: Instruction<Q, A>,

pub fn iter(&self) -> Iter<'_, I>

returns an iterator over the elements.

pub fn iter_mut(&mut self) -> IterMut<'_, I>

returns a mutable iterator over the elements.

Source

impl<const N: usize, I, Q, A> ProgramBase<[I; N], Q, A>
where Q: RawState, I: Instruction<Q, A>,

pub fn iter(&self) -> Iter<'_, I>

returns an iterator over the elements.

pub fn iter_mut(&mut self) -> IterMut<'_, I>

returns a mutable iterator over the elements.

Source

impl<I, Q, A> ProgramBase<Vec<I>, Q, A, I>
where Q: RawState, I: Instruction<Q, A>,

pub fn iter(&self) -> Iter<'_, I>

returns an iterator over the elements.

pub fn iter_mut(&mut self) -> IterMut<'_, I>

returns a mutable iterator over the elements.