pub trait Driver<Q, A>{
// Required methods
fn current_position(&self) -> usize;
fn current_state(&self) -> State<&Q>;
}Expand description
The Driver is the basis for all compatible actors within the system. Each
implementation is required to define the type of internal store it will use to
manage its data. This abstraction allows for flexibility in the choice of data structures,
enabling the actor to adapt to various use cases and performance requirements.
Required Methods
Sourcefn current_position(&self) -> usize
fn current_position(&self) -> usize
returns the current position of the driver.
Sourcefn current_state(&self) -> State<&Q>
fn current_state(&self) -> State<&Q>
returns a view of the current state of the driver.